@@ -11,8 +11,10 @@ describe Rouge::Lexers::Docker do
       assert_guess :filename => 'Dockerfile'
       assert_guess :filename => 'docker.docker'
       assert_guess :filename => 'some.Dockerfile'
+      assert_guess :filename => 'Dockerfile.some'
       assert_guess :filename => 'Containerfile'
       assert_guess :filename => 'some.Containerfile'
+      assert_guess :filename => 'Containerfile.some'
     end
 
     it 'guesses by mimetype' do
