@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 describe Rouge::Lexers::Haskell do
   let(:subject) { Rouge::Lexers::Haskell.new }
@@ -8,6 +9,7 @@ describe Rouge::Lexers::Haskell do
 
     it 'guesses by filename' do
       assert_guess :filename => 'foo.hs'
+      assert_guess :filename => 'foo.hs-boot'
     end
 
     it 'guesses by mimetype' do
