@@ -8,7 +8,7 @@ describe Rouge::Lexers::Smalltalk do
     include Support::Guessing
 
     it 'guesses by filename' do
-      assert_guess :filename => 'foo.st'
+      assert_guess :filename => 'foo.st', :source => ''
     end
 
     it 'guesses by mimetype' do
